@@ -49,7 +49,6 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     KCModule(PrintKCMFactory::componentData(), parent, args),
     ui(new Ui::PrintKCM),
     m_lastError(-1), // Force the error to run on the first time
-    m_gotServerSettings(false),
     m_serverRequest(0)
 {
     KAboutData *aboutData;
@@ -90,6 +89,7 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     m_allowPrintringFromInternet->setCheckable(true);
     m_allowPrintringFromInternet->setEnabled(false);
     connect(m_shareConnectedPrinters, SIGNAL(toggled(bool)), m_allowPrintringFromInternet, SLOT(setEnabled(bool)));
+    connect(m_shareConnectedPrinters, SIGNAL(toggled(bool)), ui->printerDesc, SLOT(enableShareCheckBox(bool)));
     systemMenu->addSeparator();
     m_allowRemoteAdmin = systemMenu->addAction(i18nc("@action:intoolbar","Allow remote administration"));
     m_allowRemoteAdmin->setCheckable(true);
@@ -120,8 +120,18 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
 
     // Force the model update AFTER we setup the error signal
     m_model->update();
-}
 
+    // Make sure we update our server settings if the user change it on
+    // another interface
+    connect(KCupsConnection::global(), SIGNAL(serverAudit(QString)), this, SLOT(getServerSettings()));
+    connect(KCupsConnection::global(), SIGNAL(serverRestarted(QString)), this, SLOT(getServerSettings()));
+    connect(KCupsConnection::global(), SIGNAL(serverStarted(QString)), this, SLOT(getServerSettings()));
+    connect(KCupsConnection::global(), SIGNAL(serverStopped(QString)), this, SLOT(getServerSettings()));
+
+    // We need to know the server settings so we disable the
+    // share printer checkbox if sharing is disabled on the server
+    getServerSettings();
+}
 
 PrintKCM::~PrintKCM()
 {
@@ -310,15 +320,6 @@ void PrintKCM::getServerSettingsFinished()
 {
     KCupsRequest *request = qobject_cast<KCupsRequest *>(sender());
 
-    // This is odd, when the server settings didn't change
-    // we get IPP_SERVICE_UNAVAILABLE and a message of "Not Modified"
-    // but we can't rely on the message since it's localized
-    kDebug() << request->errorMsg();
-    if (m_gotServerSettings == true && request->error() == IPP_SERVICE_UNAVAILABLE) {
-        request->deleteLater();
-        return;
-    }
-
     // When we don't have any destinations error is set to IPP_NOT_FOUND
     // we can safely ignore the error since it DOES bring the server settings
     bool error = request->hasError() && request->error() != IPP_NOT_FOUND;
@@ -327,7 +328,6 @@ void PrintKCM::getServerSettingsFinished()
     m_showSharedPrinters->setEnabled(!error);
 #endif // CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR < 6
     m_shareConnectedPrinters->setEnabled(!error);
-    m_allowPrintringFromInternet->setEnabled(!error);
     m_allowRemoteAdmin->setEnabled(!error);
     m_allowUsersCancelAnyJob->setEnabled(!error);
 
@@ -338,7 +338,6 @@ void PrintKCM::getServerSettingsFinished()
                                    i18nc("@title:window", "Failed"));
     } else {
         KCupsServer server = request->serverSettings();
-        m_gotServerSettings = true;
 
 #if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR < 6
         m_showSharedPrinters->setChecked(server.showSharedPrinters());
